@@ -558,6 +558,8 @@ class ReceptorEstimator:
         l1 : float, optional
             Whether to sample points that correspond to a specific L1-norm. 
             By default None.
+        relative : bool, optional
+            Whether `B` are relative capture values, by default True.
 
         Returns
         -------
@@ -573,9 +575,9 @@ class ReceptorEstimator:
             return sample_in_hull(P, n, seed=seed, engine=engine)
         else:
             # sample within a simplex
-            l1 = P.sum(axis=-1)
+            l1_P = P.sum(axis=-1)
             # remove zero intensity
-            P = P[l1 != 0]
+            P = P[l1_P != 0]
             # reduce to barycentric coordinates and sample within that hull
             P = barycentric_dim_reduction(P)
             X = sample_in_hull(P, n, seed=seed, engine=engine)
@@ -910,9 +912,9 @@ class ReceptorEstimator:
         else:
             raise NameError(f"Model name `{model}` unknown.")
             
-        self.X = X
-        self.B = B
         if internal:
+            self.X = X
+            self.B = B
             return self
         return X, B
     
@@ -999,10 +1001,10 @@ class ReceptorEstimator:
             **opt_kwargs
         )
         
-        self.X = X
-        self.B = B
-        self.scales = scales
         if internal:
+            self.X = X
+            self.B = B
+            self.scales = scales
             return self
         return X, scales, B
     
@@ -1107,10 +1109,10 @@ class ReceptorEstimator:
             **opt_kwargs 
         )
         
-        self.X = X
-        self.P = P
-        self.B = B
         if internal:
+            self.X = X
+            self.P = P
+            self.B = B
             return self
         return X, P, B
     
@@ -1187,9 +1189,9 @@ class ReceptorEstimator:
             **opt_kwargs
         )
         
-        self.X = X
-        self.B = B
         if internal:
+            self.X = X
+            self.B = B
             return self
         return X, B
     
@@ -1276,10 +1278,10 @@ class ReceptorEstimator:
             **opt_kwargs
         )
         
-        self.X = X
-        self.B = B
-        self.Bvar = Bvar
         if internal:
+            self.X = X
+            self.B = B
+            self.Bvar = Bvar
             return self
         return X, B, Bvar
     
